@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   MenuLibre - Advanced fd.o Compliant Menu Editor
-#   Copyright (C) 2012-2023 Sean Davis <sean@bluesabre.org>
+#   Copyright (C) 2012-2024 Sean Davis <sean@bluesabre.org>
 #   Copyright (C) 2017-2018 OmegaPhil <OmegaPhil@startmail.com>
 #
 #   This program is free software: you can redistribute it and/or modify it
@@ -37,7 +37,7 @@ old_psutil_format = isinstance(psutil.Process.username, property)
 
 
 def enum(**enums):
-    """Add enumarations to Python."""
+    """Add enumerations to Python."""
     return type('Enum', (), enums)
 
 
